==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_functions/mp0116_getgriddataonly_001_result/FIELDS.java <==

package net.datastream.schemas.mp_functions.mp0116_getgriddataonly_001_result;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}FIELD" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="viewtype" type="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}GRID_TYPE_type" />
 *       &lt;attribute name="visibleColumn" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="visiblerowcount" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "field"
})
@XmlRootElement(name = "FIELDS")
public class FIELDS {

    @XmlElement(name = "FIELD", required = true)
    protected List<FIELD> field;
    @XmlAttribute(name = "viewtype")
    protected GRID_TYPE_Type viewtype;
    @XmlAttribute(name = "visibleColumn")
    protected String visibleColumn;
    @XmlAttribute(name = "visiblerowcount")
    protected String visiblerowcount;

    /**
     * Gets the value of the field property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the field property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFIELD().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link FIELD }
     * 
     * 
     */
    public List<FIELD> getFIELD() {
        if (field == null) {
            field = new ArrayList<FIELD>();
        }
        return this.field;
    }

    /**
     * Obtient la valeur de la propriété viewtype.
     * 
     * @return
     *     possible object is
     *     {@link GRID_TYPE_Type }
     *     
     */
    public GRID_TYPE_Type getViewtype() {
        return viewtype;
    }

    /**
     * Définit la valeur de la propriété viewtype.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID_TYPE_Type }
     *     
     */
    public void setViewtype(GRID_TYPE_Type value) {
        this.viewtype = value;
    }

    /**
     * Obtient la valeur de la propriété visibleColumn.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVisibleColumn() {
        return visibleColumn;
    }

    /**
     * Définit la valeur de la propriété visibleColumn.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVisibleColumn(String value) {
        this.visibleColumn = value;
    }

    /**
     * Obtient la valeur de la propriété visiblerowcount.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVisiblerowcount() {
        return visiblerowcount;
    }

    /**
     * Définit la valeur de la propriété visiblerowcount.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVisiblerowcount(String value) {
        this.visiblerowcount = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_functions/mp0116_getgriddataonly_001_result/FIELDS.java <==

package net.datastream.schemas.mp_functions.mp0116_getgriddataonly_001_result;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}FIELD" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="viewtype" type="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}GRID_TYPE_type" />
 *       &lt;attribute name="visibleColumn" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="visiblerowcount" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "field"
})
@XmlRootElement(name = "FIELDS")
public class FIELDS {

    @XmlElement(name = "FIELD", required = true)
    protected List<FIELD> field;
    @XmlAttribute(name = "viewtype")
    protected GRID_TYPE_Type viewtype;
    @XmlAttribute(name = "visibleColumn")
    protected String visibleColumn;
    @XmlAttribute(name = "visiblerowcount")
    protected String visiblerowcount;

    /**
     * Gets the value of the field property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the field property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFIELD().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link FIELD }
     * 
     * 
     */
    public List<FIELD> getFIELD() {
        if (field == null) {
            field = new ArrayList<FIELD>();
        }
        return this.field;
    }

    /**
     * Gets the value of the viewtype property.
     * 
     * @return
     *     possible object is
     *     {@link GRID_TYPE_Type }
     *     
     */
    public GRID_TYPE_Type getViewtype() {
        return viewtype;
    }

    /**
     * Sets the value of the viewtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID_TYPE_Type }
     *     
     */
    public void setViewtype(GRID_TYPE_Type value) {
        this.viewtype = value;
    }

    /**
     * Gets the value of the visibleColumn property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVisibleColumn() {
        return visibleColumn;
    }

    /**
     * Sets the value of the visibleColumn property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVisibleColumn(String value) {
        this.visibleColumn = value;
    }

    /**
     * Gets the value of the visiblerowcount property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVisiblerowcount() {
        return visiblerowcount;
    }

    /**
     * Sets the value of the visiblerowcount property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVisiblerowcount(String value) {
        this.visiblerowcount = value;
    }

}
